@@ -102,6 +102,7 @@ from .zalioss import oss_connect
 
 # zexcel
 from .zexcel import trans_excel_to_csv
+from .zexcel import trans_csv_to_excel
 from .zexcel import read_csv_dict
 from .zexcel import read_csv_rows
 from .zexcel import read_csv_head
@@ -110,6 +111,8 @@ from .zexcel import get_excel_sheet
 from .zexcel import read_excel_head
 from .zexcel import read_excel_rows
 from .zexcel import read_excel_items
+from .zexcel import save_excel_rows
+from .zexcel import save_excel_items
 
 
 # zfunction
@@ -118,6 +121,7 @@ from .zfunction import list_or_args
 
 # zdict
 from .zdict import dict_extract
+from .zdict import dict_recursive_get
 
 
 # zarea_matcher
